@@ -18,7 +18,7 @@ size_a.three_way_mixed_cxbina.model_7_c <-  function(alpha, beta, delta, b, c, n
 	{
 		lambda <- 0.25*a*b*c*n*delta*delta
 	}
-	beta.calculated <- beta(alpha, dfn, dfd, lambda)
+	beta.calculated <- Beta(alpha, dfn, dfd, lambda)
 	if (is.nan(beta.calculated) || beta.calculated < beta )
 	{
    warning(paste("Given parameter will result in too high power.",
