@@ -17,7 +17,7 @@ size_n.two_way_nested.model_1_test_factor_a <-  function(alpha, beta, delta, a,
 	{
 		lambda <- 0.25*a*b*n*delta*delta
 	}
-	beta.calculated <- beta(alpha, dfn, dfd, lambda)
+	beta.calculated <- Beta(alpha, dfn, dfd, lambda)
 	if (is.nan(beta.calculated) || beta.calculated < beta )
 	{
    warning(paste("Given parameter will result in too high power.",
